@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004, 2005, 2006  Free Software Foundation, Inc.
+# Copyright (C) 2003-2013 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,11 +11,11 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Automake::Variable;
+
+use 5.006;
 use strict;
 use Carp;
 
@@ -73,7 +73,7 @@ Automake::Variable - support for variable definitions
   # $var->conditions->conds is a list of Automake::Condition.)
   my @conds = $var->conditions->conds
 
-  # Accessing to the definition in Condition $cond.
+  # Access to the definition in Condition $cond.
   # $def is an Automake::VarDef.
   my $def = $var->def ($cond);
   if ($def)
@@ -130,7 +130,10 @@ non-object).
 
 =cut
 
-my $_VARIABLE_PATTERN = '^[.A-Za-z0-9_@]+' . "\$";
+my $_VARIABLE_CHARACTERS = '[.A-Za-z0-9_@]+';
+my $_VARIABLE_PATTERN = '^' . $_VARIABLE_CHARACTERS . "\$";
+my $_VARIABLE_RECURSIVE_PATTERN =
+    '^([.A-Za-z0-9_@]|\$[({]' . $_VARIABLE_CHARACTERS . '[})]?)+' . "\$";
 
 # The order in which variables should be output.  (May contain
 # duplicates -- only the first occurrence matters.)
@@ -138,7 +141,7 @@ my @_var_order;
 
 # This keeps track of all variables defined by &_gen_varname.
 # $_gen_varname{$base} is a hash for all variables defined with
-# prefix `$base'.  Values stored in this hash are the variable names.
+# prefix '$base'.  Values stored in this hash are the variable names.
 # Keys have the form "(COND1)VAL1(COND2)VAL2..." where VAL1 and VAL2
 # are the values of the variable for condition COND1 and COND2.
 my %_gen_varname = ();
@@ -154,20 +157,18 @@ my %_gen_varname_n = ();
 # Macros accessible via aclocal.
 my %_am_macro_for_var =
   (
-   ANSI2KNR => 'AM_C_PROTOTYPES',
    CCAS => 'AM_PROG_AS',
    CCASFLAGS => 'AM_PROG_AS',
    EMACS => 'AM_PATH_LISPDIR',
    GCJ => 'AM_PROG_GCJ',
    LEX => 'AM_PROG_LEX',
-   LIBTOOL => 'AC_PROG_LIBTOOL',
+   LIBTOOL => 'LT_INIT',
    lispdir => 'AM_PATH_LISPDIR',
    pkgpyexecdir => 'AM_PATH_PYTHON',
    pkgpythondir => 'AM_PATH_PYTHON',
    pyexecdir => 'AM_PATH_PYTHON',
    PYTHON => 'AM_PATH_PYTHON',
    pythondir => 'AM_PATH_PYTHON',
-   U => 'AM_C_PROTOTYPES',
    );
 
 # Macros shipped with Autoconf.
@@ -179,11 +180,13 @@ my %_ac_macro_for_var =
    CXX => 'AC_PROG_CXX',
    CXXFLAGS => 'AC_PROG_CXX',
    F77 => 'AC_PROG_F77',
-   F77FLAGS => 'AC_PROG_F77',
+   FFLAGS => 'AC_PROG_F77',
    FC => 'AC_PROG_FC',
    FCFLAGS => 'AC_PROG_FC',
    OBJC => 'AC_PROG_OBJC',
    OBJCFLAGS => 'AC_PROG_OBJC',
+   OBJCXX => 'AC_PROG_OBJCXX',
+   OBJCXXFLAGS => 'AC_PROG_OBJCXX',
    RANLIB => 'AC_PROG_RANLIB',
    UPC => 'AM_PROG_UPC',
    UPCFLAGS => 'AM_PROG_UPC',
@@ -191,9 +194,9 @@ my %_ac_macro_for_var =
    );
 
 # The name of the configure.ac file.
-my $configure_ac = find_configure_ac;
+my $configure_ac;
 
-# Variables that can be overriden without complaint from -Woverride
+# Variables that can be overridden without complaint from -Woverride
 my %_silent_variable_override =
   (AM_MAKEINFOHTMLFLAGS => 1,
    AR => 1,
@@ -352,7 +355,7 @@ sub reset ()
 =item C<var ($varname)>
 
 Return the C<Automake::Variable> object for the variable
-named C<$varname> if defined.   Return 0 otherwise.
+named C<$varname> if defined.  Return 0 otherwise.
 
 =cut
 
@@ -465,12 +468,13 @@ sub _check_ambiguous_condition ($$$)
   my $var = $self->name;
   my ($message, $ambig_cond) = $self->conditions->ambiguous_p ($var, $cond);
 
-  # We allow silent variables to be overridden silently.
-  my $def = $self->def ($cond);
-  if ($message && !($def && $def->pretty == VAR_SILENT))
+  # We allow silent variables to be overridden silently,
+  # by either silent or non-silent variables.
+  my $def = $self->def ($ambig_cond);
+  if ($message && $def->pretty != VAR_SILENT)
     {
       msg 'syntax', $where, "$message ...", partial => 1;
-      msg_var ('syntax', $var, "... `$var' previously defined here");
+      msg_var ('syntax', $var, "... '$var' previously defined here");
       verb ($self->dump);
     }
 }
@@ -524,7 +528,7 @@ sub output ($@)
   foreach my $cond (@conds)
     {
       my $def = $self->def ($cond);
-      prog_error ("unknown condition `" . $cond->human . "' for `"
+      prog_error ("unknown condition '" . $cond->human . "' for '"
 		  . $self->name . "'")
 	unless $def;
 
@@ -672,8 +676,8 @@ sub has_conditional_contents ($)
 
   # Traverse the variable recursively until we
   # find a variable defined conditionally.
-  # Use `die' to abort the traversal, and pass it `$full_cond'
-  # to we can find easily whether the `eval' block aborted
+  # Use 'die' to abort the traversal, and pass it '$full_cond'
+  # to we can find easily whether the 'eval' block aborted
   # because we found a condition, or for some other error.
   eval
     {
@@ -743,8 +747,8 @@ sub scan_variable_expansions ($)
   while ($text =~ /(?<!\$)\$(?:\{([^\}]*)\}|\(([^\)]*)\))/g)
     {
       my $var = $1 || $2;
-      # The occurence may look like $(string1[:subst1=[subst2]]) but
-      # we want only `string1'.
+      # The occurrence may look like $(string1[:subst1=[subst2]]) but
+      # we want only 'string1'.
       $var =~ s/:[^:=]*=[^=]*$//;
       push @result, $var;
     }
@@ -773,8 +777,17 @@ sub check_variable_expansions ($$)
 	  # Mention this in the diagnostic.
 	  my $gnuext = "";
 	  $gnuext = "\n(probably a GNU make extension)" if $var =~ / /;
-	  msg ('portability', $where,
-	       "$var: non-POSIX variable name$gnuext");
+	  # Accept recursive variable expansions if so desired
+	  # (we hope they are rather portable in practice).
+	  if ($var =~ /$_VARIABLE_RECURSIVE_PATTERN/o)
+	    {
+	      msg ('portability-recursive', $where,
+		   "$var: non-POSIX recursive variable expansion$gnuext");
+	    }
+	  else
+	    {
+	      msg ('portability', $where, "$var: non-POSIX variable name$gnuext");
+	    }
 	}
     }
 }
@@ -789,7 +802,7 @@ C<$varname>: the name of the variable being defined.
 
 C<$owner>: owner of the variable (one of C<VAR_MAKEFILE>,
 C<VAR_CONFIGURE>, or C<VAR_AUTOMAKE>, defined by L<Automake::VarDef>).
-Variables can be overriden, provided the new owner is not weaker
+Variables can be overridden, provided the new owner is not weaker
 (C<VAR_AUTOMAKE> < C<VAR_CONFIGURE> < C<VAR_MAKEFILE>).
 
 C<$type>: the type of the assignment (C<''> for C<FOO = bar>,
@@ -832,14 +845,14 @@ sub define ($$$$$$$$)
 			       || $pretty == VAR_SILENT
 			       || $pretty == VAR_SORTED);
 
-  error $where, "bad characters in variable name `$var'"
+  error $where, "bad characters in variable name '$var'"
     if $var !~ /$_VARIABLE_PATTERN/o;
 
-  # `:='-style assignments are not acknowledged by POSIX.  Moreover it
+  # ':='-style assignments are not acknowledged by POSIX.  Moreover it
   # has multiple meanings.  In GNU make or BSD make it means "assign
   # with immediate expansion", while in OSF make it is used for
   # conditional assignments.
-  msg ('portability', $where, "`:='-style assignments are not portable")
+  msg ('portability', $where, "':='-style assignments are not portable")
     if $type eq ':';
 
   check_variable_expansions ($value, $where);
@@ -868,11 +881,11 @@ sub define ($$$$$$$$)
       if ($def->type ne $type && $def->owner == VAR_AUTOMAKE)
 	{
 	  error ($def->location,
-		 "Automake variable `$var' was set with `"
-		 . $def->type . "=' here...", partial => 1);
-	  error ($where, "... and is now set with `$type=' here.");
+		 "Automake variable '$var' was set with '"
+		 . $def->type . "=' here ...", partial => 1);
+	  error ($where, "... and is now set with '$type=' here.");
 	  prog_error ("Automake variable assignments should be consistently\n"
-		      . "defined with the same sign.");
+		      . "defined with the same sign");
 	}
 
       # If Automake tries to override a value specified by the user,
@@ -882,15 +895,15 @@ sub define ($$$$$$$$)
 	  if (! exists $_silent_variable_override{$var})
 	    {
 	      my $condmsg = ($cond == TRUE
-			     ? '' : (" in condition `" . $cond->human . "'"));
+			     ? '' : (" in condition '" . $cond->human . "'"));
 	      msg_cond_var ('override', $cond, $var,
-			    "user variable `$var' defined here$condmsg...",
+			    "user variable '$var' defined here$condmsg ...",
 			    partial => 1);
 	      msg ('override', $where,
-		   "... overrides Automake variable `$var' defined here");
+		   "... overrides Automake variable '$var' defined here");
 	    }
 	  verb ("refusing to override the user definition of:\n"
-		. $self->dump ."with `" . $cond->human . "' => `$value'");
+		. $self->dump ."with '" . $cond->human . "' => '$value'");
 	  return;
 	}
     }
@@ -979,16 +992,16 @@ sub define ($$$$$$$$)
 	  #   endif
 	  #   X += Z
 	  # should be rejected because X is not defined for all conditions
-	  # where `+=' applies.
+	  # where '+=' applies.
 	  my $undef_cond = $self->not_always_defined_in_cond ($cond);
 	  if (! $undef_cond->false)
 	    {
 	      error ($where,
-		     "Cannot apply `+=' because `$var' is not defined "
+		     "cannot apply '+=' because '$var' is not defined "
 		     . "in\nthe following conditions:\n  "
 		     . join ("\n  ", map { $_->human } $undef_cond->conds)
-		     . "\nEither define `$var' in these conditions,"
-		     . " or use\n`+=' in the same conditions as"
+		     . "\neither define '$var' in these conditions,"
+		     . " or use\n'+=' in the same conditions as"
 		     . " the definitions.");
 	    }
 	  else
@@ -1015,7 +1028,7 @@ sub define ($$$$$$$$)
 	if ! $new_var && $owner < $def->owner;
 
       # Assignments to a macro set its location.  We don't adjust
-      # locations for `+='.  Ideally I suppose we would associate
+      # locations for '+='.  Ideally I suppose we would associate
       # line numbers with random bits of text.
       $def = new Automake::VarDef ($var, $value, $comment, $where->clone,
 				   $type, $owner, $pretty);
@@ -1066,7 +1079,7 @@ For debugging.
 
 sub variables_dump ()
 {
-  my $text = "All variables:\n{\n";
+  my $text = "all variables:\n{\n";
   foreach my $var (sort { $a->name cmp $b->name } variables)
     {
       $text .= $var->dump;
@@ -1120,6 +1133,9 @@ sub require_variables ($$$@)
   my $res = 0;
   $reason .= ' but ' unless $reason eq '';
 
+  $configure_ac = find_configure_ac
+    unless defined $configure_ac;
+
  VARIABLE:
   foreach my $var (@vars)
     {
@@ -1127,7 +1143,7 @@ sub require_variables ($$$@)
       next VARIABLE
 	if vardef ($var, $cond);
 
-      my $text = "$reason`$var' is undefined\n";
+      my $text = "$reason'$var' is undefined\n";
       my $v = var $var;
       if ($v)
 	{
@@ -1144,20 +1160,20 @@ sub require_variables ($$$@)
       if (exists $_am_macro_for_var{$var})
 	{
 	  my $mac = $_am_macro_for_var{$var};
-	  $text .= "  The usual way to define `$var' is to add "
-	    . "`$mac'\n  to `$configure_ac' and run `aclocal' and "
-	    . "`autoconf' again.";
+	  $text .= "  The usual way to define '$var' is to add "
+	    . "'$mac'\n  to '$configure_ac' and run 'aclocal' and "
+	    . "'autoconf' again.";
 	  # aclocal will not warn about undefined macros unless it
 	  # starts with AM_.
-	  $text .= "\n  If `$mac' is in `$configure_ac', make sure\n"
+	  $text .= "\n  If '$mac' is in '$configure_ac', make sure\n"
 	    . "  its definition is in aclocal's search path."
 	    unless $mac =~ /^AM_/;
 	}
       elsif (exists $_ac_macro_for_var{$var})
 	{
-	  $text .= "  The usual way to define `$var' is to add "
-	    . "`$_ac_macro_for_var{$var}'\n  to `$configure_ac' and "
-	    . "run `autoconf' again.";
+	  $text .= "  The usual way to define '$var' is to add "
+	    . "'$_ac_macro_for_var{$var}'\n  to '$configure_ac' and "
+	    . "run 'autoconf' again.";
 	}
 
       error $where, $text, uniq_scope => US_GLOBAL;
@@ -1263,13 +1279,13 @@ following arguments:
                    traversing
    $val,        -- the item (i.e., filename) to process
    $cond,       -- the Condition for the $var definition we are
-                   examinating (ignoring the recursion context)
+                   examining (ignoring the recursion context)
    $full_cond)  -- the full Condition, taking into account
                    conditions inherited from parent variables
                    during recursion
 
-If C<inner_expand> is set, variable references occuring in filename
-(as in C<$(BASE).ext>) are expansed before the filename is passed to
+If C<inner_expand> is set, variable references occurring in filename
+(as in C<$(BASE).ext>) are expanded before the filename is passed to
 C<&fun_item>.
 
 If C<skip_ac_subst> is set, Autoconf @substitutions@ will be skipped,
@@ -1299,7 +1315,7 @@ recursive calls).
 
 =cut
 
-# Contains a stack of `from' and `to' parts of variable
+# Contains a stack of 'from' and 'to' parts of variable
 # substitutions currently in force.
 my @_substfroms;
 my @_substtos;
@@ -1328,7 +1344,7 @@ sub _do_recursive_traversal ($$&&$$$$)
 
   if ($var->{'scanned'} == $_traversal)
     {
-      err_var $var, "variable `" . $var->name() . "' recursively defined";
+      err_var $var, "variable '" . $var->name() . "' recursively defined";
       return ();
     }
   $var->{'scanned'} = $_traversal;
@@ -1357,7 +1373,7 @@ sub _do_recursive_traversal ($$&&$$$$)
 	  my $val = shift @to_process;
 	  # If $val is a variable (i.e. ${foo} or $(bar), not a filename),
 	  # handle the sub variable recursively.
-	  # (Backslashes before `}' and `)' within brackets are here to
+	  # (Backslashes before '}' and ')' within brackets are here to
 	  # please Emacs's indentation.)
 	  if ($val =~ /^\$\{([^\}]*)\}$/ || $val =~ /^\$\(([^\)]*)\)$/)
 	    {
@@ -1399,7 +1415,7 @@ sub _do_recursive_traversal ($$&&$$$$)
 	      next;
 	    }
 	  # Try to expand variable references inside filenames such as
-	  # `$(NAME).txt'.  We do not handle `:.foo=.bar'
+	  # '$(NAME).txt'.  We do not handle ':.foo=.bar'
 	  # substitutions, but it would make little sense to use this
 	  # here anyway.
 	  elsif ($inner_expand
@@ -1489,7 +1505,7 @@ sub _hash_varname ($)
 
 # _hash_values (@VALUES)
 # ----------------------
-# Hash @VALUES for %_gen_varname.  @VALUES shoud be a list
+# Hash @VALUES for %_gen_varname.  @VALUES should be a list
 # of pairs: ([$cond, @values], [$cond, @values], ...).
 # See _gen_varname() below.
 sub _hash_values (@)
@@ -1504,7 +1520,7 @@ sub _hash_values (@)
 }
 # ($VARNAME, $GENERATED)
 # _gen_varname ($BASE, @DEFINITIONS)
-# ---------------------------------
+# ----------------------------------
 # Return a variable name starting with $BASE, that will be
 # used to store definitions @DEFINITIONS.
 # @DEFINITIONS is a list of pair [$COND, @OBJECTS].
